[Yapcom-commit] rev 108 - in yapcom/trunk: . db lib/YAPC t t/lib/YAPC/Test templates

[prev] [thread] [next] [lurker] [Date index for 2003/12/4]

From: svn
Subject: [Yapcom-commit] rev 108 - in yapcom/trunk: . db lib/YAPC t t/lib/YAPC/Test templates
Date: 16:21 on 04 Dec 2003
Author: jon
Date: 2003-12-04 16:21:09 +0200 (Thu, 04 Dec 2003)
New Revision: 108

Modified:
   yapcom/trunk/README
   yapcom/trunk/db/config.sample
   yapcom/trunk/lib/YAPC/Config.pm
   yapcom/trunk/lib/YAPC/Organizer.pm
   yapcom/trunk/t/03-web-adduser.t
   yapcom/trunk/t/05-web-proposals.t
   yapcom/trunk/t/07-web-change-data.t
   yapcom/trunk/t/09-web-change-password.t
   yapcom/trunk/t/10-use-html-template.t
   yapcom/trunk/t/11-web-admin.t
   yapcom/trunk/t/13-change-proposal.t
   yapcom/trunk/t/lib/YAPC/Test/Data.pm
   yapcom/trunk/templates/admin_list_proposals.tmpl
   yapcom/trunk/templates/email_sent.tmpl
   yapcom/trunk/templates/header.tmpl
   yapcom/trunk/templates/index.tmpl
   yapcom/trunk/templates/list_my_proposals.tmpl
   yapcom/trunk/templates/list_people.tmpl
   yapcom/trunk/templates/login.tmpl
   yapcom/trunk/templates/logout.tmpl
   yapcom/trunk/templates/message.tmpl
   yapcom/trunk/templates/navigation.tmpl
   yapcom/trunk/templates/news.tmpl
   yapcom/trunk/templates/organizers.tmpl
   yapcom/trunk/templates/person.tmpl
   yapcom/trunk/templates/speakers.tmpl
   yapcom/trunk/templates/sponsors.tmpl
   yapcom/trunk/templates/sponsorship.tmpl
   yapcom/trunk/templates/talk.tmpl
   yapcom/trunk/templates/user_account.tmpl
Log:
s/REQUEST_URI/PATH_INFO/g; added config 'cgi_path', updated README

Modified: yapcom/trunk/README
===================================================================
--- yapcom/trunk/README	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/README	2003-12-04 14:21:09 UTC (rev 108)
@@ -12,8 +12,8 @@
 - perl Makefile.PL
 - check the path of perl in cgi/yapc.pl, and t/*.t
 - change the file db/config (sample is provided). Change at least
-SITE_DIR, SITE_EMAIL, and SITE_ADMIN. Each line in the config file
-MUST be:
+CGI_PATH, SITE_DIR, SITE_EMAIL, and SITE_ADMIN. Each line in the config
+file MUST be:
 
 	KEY = VAL
 
@@ -23,6 +23,7 @@
 	around the '=' and at the beginning and end of the line are
 	stripped. Valid KEY's (and defaults) are:
 
+	CGI_PATH (/YAPC/2004)
 	SITE_DIR (/home/gabor/projects/perl/perl.org.il/YAPC/dev)
 	SITE_EMAIL (yapc@xxxx.xxx.xx)
 	SITE_ADMIN (gabor@xxx.xx.xx)			* multiple
@@ -39,12 +40,15 @@
 
 - In the virtual host in the apache configuration file write something like this:
 
+ScriptAlias   /cgidir/  /path/to/installation/cgi/
+Alias /docsdir /path/to/installation/docs
+Alias /filesdir /path/to/installation/files
+Alias /htmldir /path/to/installation/html
 
-Alias /virtual/subdir/files/ /path/to/installation/files/
-Alias /virtual/subdir/docs/ /path/to/installation/docs/
-Alias /virtual/subdir/html/ /path/to/installation/html/
-ScriptAliasMatch   ^/virtual/subdir/[a-zA-Z0-9_.-]*$  /path/to/installation/cgi/yapc.pl
-
+<Directory /path/to/installation/cgi>
+    Options FollowSymLinks
+    AllowOverride None
+</Directory>
 <Directory /path/to/installation/db>
         Deny from all
 </Directory>
@@ -52,7 +56,6 @@
         Deny from all
 </Directory>
 
-
 CHANGES
 ---------
 0.10  2003.12.03

Modified: yapcom/trunk/db/config.sample
===================================================================
--- yapcom/trunk/db/config.sample	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/db/config.sample	2003-12-04 14:21:09 UTC (rev 108)
@@ -1,3 +1,4 @@
-SITE_DIR = /home/yehuda/Yapcom
+CGI_PATH = /jon/2004
+SITE_DIR = /home/jon/Yapcom/yapcom/trunk
 SITE_EMAIL = jon@xxxxxx.xx.xx
 SITE_ADMINS = jon@xxxxxx.xx.xx 

Modified: yapcom/trunk/lib/YAPC/Config.pm
===================================================================
--- yapcom/trunk/lib/YAPC/Config.pm	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/lib/YAPC/Config.pm	2003-12-04 14:21:09 UTC (rev 108)
@@ -2,7 +2,7 @@
 use FindBin;
 use strict;
 use warnings;
-our (@STORAGE, $dir, $db_dir, $db_file, $TIMEOUT, $templates_dir, $email_address);
+our (@STORAGE, $dir, $db_dir, $db_file, $TIMEOUT, $templates_dir, $email_address, $cgi_path);
 our (@proposal_languages, @proposal_lengths, @admins);
 
 my %config;
@@ -14,6 +14,7 @@
 
 $dir           = $config{'SITE_DIR'}   || "/home/gabor/projects/perl/perl.org.il/YAPC/dev";
 $email_address = $config{'SITE_EMAIL'} || 'yapc@xxxx.xxx.xx';
+$cgi_path      = $config{'CGI_PATH'}   || '/YAPC/2004';
 
 # list of e-mail address of administrators whom will have extra rights
 @admins = ($config{'SITE_ADMINS'}) ? split /[\s,]+/, $config{'SITE_ADMINS'} : qw(gabor@xxx.xx.xx);

Modified: yapcom/trunk/lib/YAPC/Organizer.pm
===================================================================
--- yapcom/trunk/t/03-web-adduser.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/03-web-adduser.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -17,9 +17,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -47,7 +47,7 @@
 # that won't change with time and we might need to have a set of tests that are installation
 # specific.
 {
-   local $ENV{REQUEST_URI} = '/list_people.html';
+   local $ENV{PATH_INFO} = '/list_people.html';
    my $webapp = YAPC::Organizer->new;
    $webapp->query(CGI->new());
    my $result = $webapp->run();
@@ -61,7 +61,7 @@
 
 ##### access the registration page for the first time
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -72,7 +72,7 @@
 
 ##### register a user
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my %user = %user1;
    $user{pauseid} = 'MYPAUSEID';
    $user{submit}  = 1;
@@ -80,7 +80,7 @@
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
    my $result = $webapp->run();
-   like($result, qr@Location: http://test-host/validation.html@, 'User registered, page redirected');
+   like($result, qr@Location: http://test-host/.*validation.html@, 'User registered, page redirected');
 
    #like($result, qr/Thank you for registering/, 'User registered');
 }
@@ -96,7 +96,7 @@
 
 # try to register with not-existing field
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my %user = %user1;
    $user{email}             = 'dudu@tomtom';
    $user{submit}            = 1;
@@ -106,13 +106,13 @@
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
    my $result = $webapp->run();
-   like($result, qr@Location: http://test-host/validation.html@, 'User registered with extra fields, page redirected');
+   like($result, qr@Location: http://test-host/.*validation.html@, 'User registered with extra fields, page redirected');
 }
 
 # try to supply value to fields we do not want to be overwrittent
 # id, acked, authcode
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my %user = %user1;
    $user{email}  = 'dudu@bad-id';
    $user{id}     = 100;
@@ -125,7 +125,7 @@
    like($result, qr/Registration failed./, 'registration failed');
 }
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my %user = %user1;
    $user{email}  = 'dudu@bad-acked';
    $user{acked}  = 100;
@@ -138,7 +138,7 @@
    like($result, qr/>Registration failed./, 'User failed to registere');
 }
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my %user = %user1;
    $user{email}    = 'dudu@bad-authcode';
    $user{authcode} = 100;
@@ -153,7 +153,7 @@
 
 ###### Login before validation
 {
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    my %user = %user1;
    $user{submit} = 1;
 
@@ -166,7 +166,7 @@
 
 ##### show information about one person before validation should fail
 {
-   local $ENV{REQUEST_URI} = '/person.html';
+   local $ENV{PATH_INFO} = '/person.html';
    my $q = CGI->new({id => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -176,7 +176,7 @@
 
 ###### validation
 {
-   local $ENV{REQUEST_URI} = '/validation.html';
+   local $ENV{PATH_INFO} = '/validation.html';
    my %user;
    $user{email}    = $user1{email};
    $user{authcode} = $authcode1;
@@ -190,7 +190,7 @@
 
 ##### check if the link to search.cpan.org shows the PAUSEID
 eval {
-   local $ENV{REQUEST_URI} = '/list_people.html';
+   local $ENV{PATH_INFO} = '/list_people.html';
    my $webapp = YAPC::Organizer->new;
    $webapp->query(CGI->new());
    my $result = $webapp->run();
@@ -200,7 +200,7 @@
 
 ##### show information about one person (without id it fails)
 {
-   local $ENV{REQUEST_URI} = '/person.html';
+   local $ENV{PATH_INFO} = '/person.html';
    my $webapp = YAPC::Organizer->new;
    $webapp->query(CGI->new());
    my $result = $webapp->run();
@@ -208,7 +208,7 @@
 }
 ##### show information about one person (with not exiting id it fails)
 {
-   local $ENV{REQUEST_URI} = '/person.html';
+   local $ENV{PATH_INFO} = '/person.html';
    my $q = CGI->new({id => 30});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -217,7 +217,7 @@
 }
 ##### show information about one person after validation
 {
-   local $ENV{REQUEST_URI} = '/person.html';
+   local $ENV{PATH_INFO} = '/person.html';
    my $q = CGI->new({id => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -227,7 +227,7 @@
 
 ###### login page
 {
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
 
@@ -240,7 +240,7 @@
 ###### login after validation
 {
    my $path = '/';
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    my %user;
 
    #$user{run} = 'login';
@@ -273,7 +273,7 @@
 ###### login with the same user from a different browser
 {
    my $path = '/';
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    my %user;
 
    #$user{run} = 'login';
@@ -301,7 +301,7 @@
 
 ###### login fails
 {
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    my %user;
 
    #$user{run} = 'login';
@@ -319,7 +319,7 @@
 ####### accessing the proposal page without logging in first
 ####### leads us to the login page with next=proposal set
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    my $webapp = YAPC::Organizer->new;
    $webapp->query();
    my $result = $webapp->run();
@@ -330,7 +330,7 @@
 ####### accessing the user account page without logging in first
 ####### leads us to the login page with next=user_account.html set
 {
-   local $ENV{REQUEST_URI} = '/user_account.html';
+   local $ENV{PATH_INFO} = '/user_account.html';
    my $webapp = YAPC::Organizer->new;
    $webapp->query();
    my $result = $webapp->run();
@@ -340,7 +340,7 @@
 
 ####### accessing the proposal page after logging in
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookie_value";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -351,7 +351,7 @@
 
 ####### accessing the proposal page after logging in but with different cookie
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=other $cookie_value";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -363,7 +363,7 @@
 
 ###### accessing the login page when the users is logged in should bring up the My YAPC page
 {
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookie_value";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -374,7 +374,7 @@
 
 ###### Accessing logout page while you are not loged in leads to the login page, next should NOT be set to logout !
 {
-   local $ENV{REQUEST_URI} = '/logout.html';
+   local $ENV{PATH_INFO} = '/logout.html';
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -385,7 +385,7 @@
 
 ###### Accessing logout page
 {
-   local $ENV{REQUEST_URI} = '/logout.html';
+   local $ENV{PATH_INFO} = '/logout.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookie_value";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -397,7 +397,7 @@
 ####### accessing the proposal page after logout (cookie is still supplied)
 ####### leads us to the login page with next=proposal.html set
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookie_value";
    my $webapp = YAPC::Organizer->new;
    $webapp->query();
@@ -408,7 +408,7 @@
 
 ####### accessing the proposal page after logging in, from the other browser
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookie_value2";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -421,7 +421,7 @@
 
 ###### show lost_validation page
 {
-   local $ENV{REQUEST_URI} = '/lost_validation.html';
+   local $ENV{PATH_INFO} = '/lost_validation.html';
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -431,7 +431,7 @@
 
 ####### get validation code if not validated yet
 {
-   local $ENV{REQUEST_URI} = '/lost_validation.html';
+   local $ENV{PATH_INFO} = '/lost_validation.html';
    my $q = CGI->new({email => 'bad-email', submit => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -441,7 +441,7 @@
 
 ## already validated
 {
-   local $ENV{REQUEST_URI} = '/lost_validation.html';
+   local $ENV{PATH_INFO} = '/lost_validation.html';
    my $q = CGI->new({email => $people[0]{email}, submit => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -451,7 +451,7 @@
 
 ###### registering without validation
 {
-   local $ENV{REQUEST_URI} = '/registration.html';
+   local $ENV{PATH_INFO} = '/registration.html';
    my %user = %{$people[1]};
    $user{run}     = 'registration';
    $user{pauseid} = 'MYPAUSEID';
@@ -460,14 +460,14 @@
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
    my $result = $webapp->run();
-   like($result, qr@Location: http://test-host/validation.html@, 'User registered, page redirected');
+   like($result, qr@Location: http://test-host/.*validation.html@, 'User registered, page redirected');
 
    #like($result, qr/Thank you for registering/, 'User registered');
 }
 
 ## validation sent (we should check the real e-mail somehow)
 {
-   local $ENV{REQUEST_URI} = '/lost_validation.html';
+   local $ENV{PATH_INFO} = '/lost_validation.html';
    my $q = CGI->new({email => $people[1]{email}, submit => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -477,7 +477,7 @@
 
 ####### access lost_password page with no data
 {
-   local $ENV{REQUEST_URI} = '/lost_password.html';
+   local $ENV{PATH_INFO} = '/lost_password.html';
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -487,7 +487,7 @@
 
 ####### get lost password
 {
-   local $ENV{REQUEST_URI} = '/lost_password.html';
+   local $ENV{PATH_INFO} = '/lost_password.html';
    my $q = CGI->new({email => 'bad-email', submit => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
@@ -497,7 +497,7 @@
 
 ## password sent (we should check the real e-mail somehow)
 {
-   local $ENV{REQUEST_URI} = '/lost_password.html';
+   local $ENV{PATH_INFO} = '/lost_password.html';
    my $q = CGI->new({email => $people[0]{email}, submit => 1});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);

Modified: yapcom/trunk/t/05-web-proposals.t
===================================================================
--- yapcom/trunk/t/05-web-proposals.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/05-web-proposals.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -17,9 +17,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -32,7 +32,7 @@
 
 ####### accessing the proposal page after logging in
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -55,7 +55,7 @@
 
 ####### sending a proposal
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
 
@@ -73,7 +73,7 @@
 
 ####### sending a proposal without a cookie
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    my %prop = %proposal;
 
    #$prop{run} = 'send_proposal';
@@ -88,7 +88,7 @@
 
 ####### sending a proposal with missing or bad information
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
 
@@ -104,7 +104,7 @@
 }
 
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
 
@@ -119,7 +119,7 @@
    is(@talks, 1, 'There is one talk in the database');
 }
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
    $prop{run}    = 'send_proposal';
@@ -134,7 +134,7 @@
 }
 
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
    $prop{run}    = 'send_proposal';
@@ -148,7 +148,7 @@
    is(@talks, 1, 'There is one talk in the database');
 }
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
    $prop{run}      = 'send_proposal';
@@ -165,7 +165,7 @@
 ##### sending proposal with the user_id of someone else
 ## maybe this should fail as it is or whould be logged
 {
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %prop = %proposal;
    $prop{run}     = 'send_proposal';
@@ -183,7 +183,7 @@
 
 ###### Accessing logout page
 {
-   local $ENV{REQUEST_URI} = '/logout.html';
+   local $ENV{PATH_INFO} = '/logout.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;

Modified: yapcom/trunk/t/07-web-change-data.t
===================================================================
--- yapcom/trunk/t/07-web-change-data.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/07-web-change-data.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -20,9 +20,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -40,7 +40,7 @@
 
 # access the change personal_info page fails if not authenticated
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
 
    #local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
@@ -52,7 +52,7 @@
 
 # update personal_information fails if not authenticated
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
 
    #local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
@@ -64,7 +64,7 @@
 
 # access to personl_info page is successful when authenticated
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -82,7 +82,7 @@
 # submit change to personl_info page when not authenticated
 # no value submitted:
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
 
    #   local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q = CGI->new({submit => 1});
@@ -96,7 +96,7 @@
 
 # submit change to personl_info page gives error when authenticated but not enough data provided.
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q = CGI->new({submit => 1});
    my $webapp = YAPC::Organizer->new;
@@ -110,7 +110,7 @@
    like($result, qr@\Q<tr><td>Company:</td><td><input  size="40" name="company" value="" /></td></tr>@,   'old company filled in correclty');
 }
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q =
      CGI->new(
@@ -134,7 +134,7 @@
 
 ##### submitted data gets updated in the database
 {
-   local $ENV{REQUEST_URI} = '/personal_info.html';
+   local $ENV{PATH_INFO} = '/personal_info.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q =
      CGI->new(

Modified: yapcom/trunk/t/09-web-change-password.t
===================================================================
--- yapcom/trunk/t/09-web-change-password.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/09-web-change-password.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -20,9 +20,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -40,7 +40,7 @@
 
 # access the change password page fails if not authenticated
 {
-   local $ENV{REQUEST_URI} = '/change_password.html';
+   local $ENV{PATH_INFO} = '/change_password.html';
 
    #local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
@@ -53,7 +53,7 @@
 # update password failes if not authenticated
 # redirect to login page and do not touch database
 {
-   local $ENV{REQUEST_URI} = '/change_password.html';
+   local $ENV{PATH_INFO} = '/change_password.html';
 
    #local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q =
@@ -76,7 +76,7 @@
 
 # fetch form by authenticated user
 {
-   local $ENV{REQUEST_URI} = '/change_password.html';
+   local $ENV{PATH_INFO} = '/change_password.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -88,7 +88,7 @@
 # submit form with bad passwords should yield an error message
 # and database should not change
 {
-   local $ENV{REQUEST_URI} = '/change_password.html';
+   local $ENV{PATH_INFO} = '/change_password.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q =
      CGI->new(
@@ -113,7 +113,7 @@
 # submit form with good password should yield a success message
 # database should be updated.
 {
-   local $ENV{REQUEST_URI} = '/change_password.html';
+   local $ENV{PATH_INFO} = '/change_password.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q =
      CGI->new(

Modified: yapcom/trunk/t/10-use-html-template.t
===================================================================
--- yapcom/trunk/t/10-use-html-template.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/10-use-html-template.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -17,9 +17,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -33,7 +33,7 @@
 =cut
 
 {
-   $ENV{REQUEST_URI} = '/registration.html';
+   $ENV{PATH_INFO} = '/registration.html';
    my %user = %user1;
    $user{pauseid} = 'MYPAUSEID';
    $user{submit}  = 1;
@@ -44,13 +44,13 @@
    my $result;
    eval {$result = $webapp->run();};
    is($@, '', 'HTML::Template loeaded');
-   like($result, qr@Location: http://test-host/validation.html@, 'User registered, page redirected');
+   like($result, qr@Location: http://test-host/.*validation.html@, 'User registered, page redirected');
 
    #like($result, qr/Thank you for registering/, 'User registered');
 }
 
 {
-   $ENV{REQUEST_URI} = '/not_existing_page.html';
+   $ENV{PATH_INFO} = '/not_existing_page.html';
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);

Modified: yapcom/trunk/t/11-web-admin.t
===================================================================
--- yapcom/trunk/t/11-web-admin.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/11-web-admin.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -19,9 +19,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -42,7 +42,7 @@
 ### this should check with the regualar pages and see if the reveal sensitive information to
 ### someone who is not an admin ?
 foreach my $page (qw(admin_list_proposals)) {
-   local $ENV{REQUEST_URI} = "/$page.html";
+   local $ENV{PATH_INFO} = "/$page.html";
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -53,7 +53,7 @@
 
 ### access page(s)  by authenticated user who is an admin
 {
-   local $ENV{REQUEST_URI} = '/list_people.html';
+   local $ENV{PATH_INFO} = '/list_people.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[2]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -64,7 +64,7 @@
 
 ### access admin page(s)  by authenticated user who is an admin
 {
-   local $ENV{REQUEST_URI} = '/admin_list_proposals.html';
+   local $ENV{PATH_INFO} = '/admin_list_proposals.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[2]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -75,7 +75,7 @@
 
 ### access admin page(s)  by unauthenticated user using run=admin  on the URL
 foreach my $page (qw(admin_list_proposals)) {
-   local $ENV{REQUEST_URI} = '/index.html';
+   local $ENV{PATH_INFO} = '/index.html';
    my $q = CGI->new({run => $page});
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);

Modified: yapcom/trunk/t/13-change-proposal.t
===================================================================
--- yapcom/trunk/t/13-change-proposal.t	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/13-change-proposal.t	2003-12-04 14:21:09 UTC (rev 108)
@@ -20,9 +20,9 @@
 # to avoid warning caused my lack of web server in the test environment
 $ENV{HTTP_HOST} = 'test-host';
 
-# $ENV{REQUEST_URI}   = 'test-uri';   #should be set for each request as we are using it
+# $ENV{PATH_INFO}   = 'test-uri';   #should be set for each request as we are using it
 $ENV{YAPCOM_NOMAIL} = 1;
-$ENV{REQUEST_URI}   = '/';
+$ENV{PATH_INFO}   = '/';
 
 BEGIN {use_ok('YAPC::Organizer');}
 
@@ -42,7 +42,7 @@
 
 # access the change personal_info page fails if not authenticated
 {
-   local $ENV{REQUEST_URI} = '/list_my_proposals.html';
+   local $ENV{PATH_INFO} = '/list_my_proposals.html';
 
    #local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
@@ -54,21 +54,21 @@
 
 # list proposals
 {
-   local $ENV{REQUEST_URI} = '/list_my_proposals.html';
+   local $ENV{PATH_INFO} = '/list_my_proposals.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
    $webapp->query($q);
    my $result = $webapp->run();
    like($result, qr@<h2>My Proposals</h2>@, 'proposals listed');
-   like($result, qr@\Q<a href="./edit_my_proposal.html?id=1">$talks[0]{subject}</a>@, '1st proposal listed');
+   like($result, qr@\Q<a href="\E.*\Q/edit_my_proposal.html?id=1">$talks[0]{subject}</a>\E@, '1st proposal listed');
    unlike($result, qr@\Q$talks[1]{subject}@, '2nd proposal NOT listed');
 
 }
 
 # access edit_my_proposal should fail for unauthenticated
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
 
    #local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
@@ -80,7 +80,7 @@
 
 # access edit_my_proposal without an id should give an error message
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q      = CGI->new();
    my $webapp = YAPC::Organizer->new;
@@ -92,7 +92,7 @@
 
 # access edit_my_proposal with an id that does not belong to the user should give an error message
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q = CGI->new({id => 2});
    my $webapp = YAPC::Organizer->new;
@@ -103,7 +103,7 @@
 
 # show details of a proposal
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my $q = CGI->new({id => 1});
    my $webapp = YAPC::Organizer->new;
@@ -117,7 +117,7 @@
 
 # submit new data without an id
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %talk = %{$talks[2]};
    $talk{submit} = 1;
@@ -130,7 +130,7 @@
 
 # submit new data to the wrong id
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %talk = %{$talks[2]};
    $talk{submit} = 1;
@@ -144,7 +144,7 @@
 
 # submit new data with good id
 {
-   local $ENV{REQUEST_URI} = '/edit_my_proposal.html';
+   local $ENV{PATH_INFO} = '/edit_my_proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookies[0]";
    my %talk = %{$talks[2]};
    $talk{submit} = 1;

Modified: yapcom/trunk/t/lib/YAPC/Test/Data.pm
===================================================================
--- yapcom/trunk/t/lib/YAPC/Test/Data.pm	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/t/lib/YAPC/Test/Data.pm	2003-12-04 14:21:09 UTC (rev 108)
@@ -87,7 +87,7 @@
 
    # register user
    {
-      local $ENV{REQUEST_URI} = '/registration.html';
+      local $ENV{PATH_INFO} = '/registration.html';
       my %user = %{$people[$i]};
       $user{submit} = 1;
       my $q      = CGI->new(\%user);
@@ -102,7 +102,7 @@
 
    ###### validate e-mail
    {
-      local $ENV{REQUEST_URI} = '/validation.html';
+      local $ENV{PATH_INFO} = '/validation.html';
       my %user;
       $user{email}    = $people[$i]{email};
       $user{authcode} = $authcode;
@@ -125,7 +125,7 @@
    my $i = shift;
 
    my $path = '/';
-   local $ENV{REQUEST_URI} = '/login.html';
+   local $ENV{PATH_INFO} = '/login.html';
    my %user;
    $user{email}    = $people[$i]{email};
    $user{password} = $people[$i]{password};
@@ -146,7 +146,7 @@
    my $t      = shift;    # talk id
    my $cookie = shift;
 
-   local $ENV{REQUEST_URI} = '/proposal.html';
+   local $ENV{PATH_INFO} = '/proposal.html';
    local $ENV{HTTP_COOKIE} = "Yapcom=$cookie";
    my %prop = %{$talks[$t]};
    $prop{submit} = 1;

Modified: yapcom/trunk/templates/admin_list_proposals.tmpl
===================================================================
--- yapcom/trunk/templates/admin_list_proposals.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/admin_list_proposals.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -4,8 +4,8 @@
 <table>
 <TMPL_LOOP NAME="talks">
 <tr><td><hr></td></tr>
-<tr><td><b><a href="talk.html?id=<TMPL_VAR NAME="talk_id">"><TMPL_VAR NAME="title"></a></b></pre></td></tr>  
-<tr><td>by: <a href="person.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="fname"> <TMPL_VAR NAME="lname"></a></td></tr>
+<tr><td><b><a href="<TMPL_VAR NAME="cgi_path">/talk.html?id=<TMPL_VAR NAME="talk_id">"><TMPL_VAR NAME="title"></a></b></pre></td></tr>  
+<tr><td>by: <a href="<TMPL_VAR NAME="cgi_path">/person.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="fname"> <TMPL_VAR NAME="lname"></a></td></tr>
 </TMPL_LOOP>
 </table>
 </p>

Modified: yapcom/trunk/templates/email_sent.tmpl
===================================================================
--- yapcom/trunk/templates/email_sent.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/email_sent.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -6,9 +6,9 @@
 </TMPL_IF>
 <TMPL_IF NAME="not_sent_authcode">
 This e-mail was already validated.<br />
-<a href="./lost_password.html">Get back your lost password</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/lost_password.html">Get back your lost password</a><br />
 or<br>
-<a href="./login.html">Login</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/login.html">Login</a><br />
 </TMPL_IF>
 <TMPL_IF NAME="sent_password">
 Password was sent

Modified: yapcom/trunk/templates/header.tmpl
===================================================================
--- yapcom/trunk/templates/header.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/header.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="iso-8859-1"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">;
-<?xml-stylesheet href="./files/style.css" type="text/css"?>
+<?xml-stylesheet href="/jonfiles/style.css" type="text/css"?>
 <html xmlns="http://www.w3.org/1999/xhtml"; lang="en" xml:lang="en">
 <head>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
-   <link rel="stylesheet" href="./files/style.css" type="text/css" />
+   <link rel="stylesheet" href="/jonfiles/style.css" type="text/css" />
    <meta name="Keywords" content="YAPC, Perl, perl , Conference ,conference, Israel, 2004" />
    <meta name="Description" content="YAPC::Israel::2004 Homepage" />
-   <title>YAPC::Israel::2004 - <TMPL_VAR NAME="title"></title>
+   <title>Jon YAPC::Israel::2004 - <TMPL_VAR NAME="title"></title>
 </head>
 <body>
 <center><h2><TMPL_VAR NAME="title"></h2></center>

Modified: yapcom/trunk/templates/index.tmpl
===================================================================
--- yapcom/trunk/templates/index.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/index.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -6,18 +6,18 @@
             <tr>
                <td width="150" valign="top">2003 November 24</td>
                <td>
-                <a href="http://www.mcgraw-hill.co.uk/">McGraw-Hill</a>; is <a href="./sponsors.html">sponsoring</a> our conference.
+                <a href="http://www.mcgraw-hill.co.uk/">McGraw-Hill</a>; is <a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">sponsoring</a> our conference.
                </td>
             </tr>
              <tr>
                <td width="150" valign="top">2003 November 24</td>
                <td>
-                <a href="http://www.focus.co.il/">Focus</a>; is <a href="./sponsors.html">sponsoring</a> our conference.
+                <a href="http://www.focus.co.il/">Focus</a>; is <a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">sponsoring</a> our conference.
                </td>
             </tr>
          </table>
          <p>
-         <font size="+1">Sponsors</font> (<a href="./sponsors.html">details</a>)
+         <font size="+1">Sponsors</font> (<a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">details</a>)
          <br>
           We would like to thank the following companies for their generous
           contributions to the YAPC::Israel::2004 Conference:
@@ -38,8 +38,8 @@
             <tr><td>Times:</td><td>09:00-19:00</td></tr>
             <tr><td>Location:</td><td><a href="http://www.idc.ac.il/">The Interdisciplinary Center Herzliya</a></td></tr>
             <tr><td>Price:</td><td>between 90-300 NIS (see details below)<br /></td></tr>
-            <tr><td>Registration:</td><td><a href="./registration.html">registration is now open</a><br /></td></tr>
-            <tr><td>Talks:</td><td>After <a href="./registration.html">registration</a> submit your <a href="./proposal.html">talk proposal</a><br /></td></tr>
+            <tr><td>Registration:</td><td><a href="<TMPL_VAR NAME="cgi_path">/registration.html">registration is now open</a><br /></td></tr>
+            <tr><td>Talks:</td><td>After <a href="<TMPL_VAR NAME="cgi_path">/registration.html">registration</a> submit your <a href="<TMPL_VAR NAME="cgi_path">/proposal.html">talk proposal</a><br /></td></tr>
          </table>
 	 </p>
          <p>

Modified: yapcom/trunk/templates/list_my_proposals.tmpl
===================================================================
--- yapcom/trunk/templates/list_my_proposals.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/list_my_proposals.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -6,7 +6,7 @@
 <p>
 <table>
 <TMPL_LOOP NAME="talks">
-  <tr><td><a href="./edit_my_proposal.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="title"></a></td><td><a href="./talk.html?id=<TMPL_VAR NAME="id">">view</a></td></tr>
+  <tr><td><a href="<TMPL_VAR NAME="cgi_path">/edit_my_proposal.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="title"></a></td><td><a href="<TMPL_VAR NAME="cgi_path">/talk.html?id=<TMPL_VAR NAME="id">">view</a></td></tr>
 </TMPL_LOOP>
 </table>
 </form>

Modified: yapcom/trunk/templates/list_people.tmpl
===================================================================
--- yapcom/trunk/templates/list_people.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/list_people.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -8,7 +8,7 @@
 <TMPL_LOOP NAME="users">
 <tr>
   <td>
-  <a href="person.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="fname"> <TMPL_VAR NAME="lname"></a>
+  <a href="<TMPL_VAR NAME="cgi_path">/person.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="fname"> <TMPL_VAR NAME="lname"></a>
   </td>
   <td><TMPL_VAR NAME="mongers"></td>
   <td><a href="http://search.cpan.org/author/<TMPL_VAR NAME="pauseid">"><TMPL_VAR NAME="pauseid"></a></td>

Modified: yapcom/trunk/templates/login.tmpl
===================================================================
--- yapcom/trunk/templates/login.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/login.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -12,10 +12,10 @@
 <tr><td>Password:</td><td><input  size="40" name="password" type="password" /></td></tr>
 <tr><td>&nbsp;</td><td><input type="submit" name="submitbtn" value="Login" /></td></tr>
 </table>
-Not yet registered ? <a href="./registration.html">Register here</a><br />
-Already registered but <a href="./lost_validation.html">lost validation code ?</a><br />
- and then <a href="./validation.html">validate it</a><br />
-Already registered but <a href="./lost_password.html">lost your password ?</a><br />
+Not yet registered ? <a href="<TMPL_VAR NAME="cgi_path">/registration.html">Register here</a><br />
+Already registered but <a href="<TMPL_VAR NAME="cgi_path">/lost_validation.html">lost validation code ?</a><br />
+ and then <a href="<TMPL_VAR NAME="cgi_path">/validation.html">validate it</a><br />
+Already registered but <a href="<TMPL_VAR NAME="cgi_path">/lost_password.html">lost your password ?</a><br />
 </form>
 </p>
 <TMPL_INCLUDE NAME="footer.tmpl">

Modified: yapcom/trunk/templates/logout.tmpl
===================================================================
--- yapcom/trunk/templates/logout.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/logout.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -5,7 +5,7 @@
 <font color="red">Error logging out</font>
 <TMPL_ELSE>
 You have successfully loged out<p />
-<a href="login.html">Login again</a>
+<a href="<TMPL_VAR NAME="cgi_path">/login.html">Login again</a>
 </TMPL_IF>
 <TMPL_INCLUDE NAME="footer.tmpl">
 

Modified: yapcom/trunk/templates/message.tmpl
===================================================================
--- yapcom/trunk/templates/message.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/message.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -9,7 +9,7 @@
 </TMPL_IF>
 <TMPL_IF NAME="personal_info_changed">
 Your personal information has been successfully updated.
-<a href="./person.html?id=<TMPL_VAR NAME="id">">view it</a>
+<a href="<TMPL_VAR NAME="cgi_path">/person.html?id=<TMPL_VAR NAME="id">">view it</a>
 </TMPL_IF>
 <TMPL_IF NAME="no_such_proposal">
 We could not find this proposal.

Modified: yapcom/trunk/templates/navigation.tmpl
===================================================================
--- yapcom/trunk/templates/navigation.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/navigation.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -1,27 +1,27 @@
-       <a href="./index.html"><img src="./files/yapsi.gif" alt="YAPC::Israel::2004 logo" /></a><br />
-         <TMPL_IF NAME="index"><b>Home</b><TMPL_ELSE><a href="./index.html">Home</a></TMPL_IF><br />
-         <TMPL_IF NAME="milestones"><b>Milestones</b><TMPL_ELSE><a href="./milestones.html">Milestones</a></TMPL_IF><br />
-         <TMPL_IF NAME="news"><b>Old News</b><TMPL_ELSE><a href="./news.html">Old News</a></TMPL_IF><br />
+       <a href="<TMPL_VAR NAME="cgi_path">/index.html"><img src="/jonfiles/yapsi.gif" alt="YAPC::Israel::2004 logo" /></a><br />
+         <TMPL_IF NAME="index"><b>Home</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/index.html">Home</a></TMPL_IF><br />
+         <TMPL_IF NAME="milestones"><b>Milestones</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/milestones.html">Milestones</a></TMPL_IF><br />
+         <TMPL_IF NAME="news"><b>Old News</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/news.html">Old News</a></TMPL_IF><br />
          Participants<br />
-         <TMPL_IF NAME="registration"> &nbsp; <b>Registration</b><TMPL_ELSE> &nbsp; <a href="./registration.html">Registration</a></TMPL_IF><br />
-         <TMPL_IF NAME="list_people"> &nbsp; <b>List participants</b><TMPL_ELSE> &nbsp; <a href="./list_people.html">List participants</a></TMPL_IF><br />
-         <TMPL_IF NAME="login"> &nbsp; <b>Personal information</b><TMPL_ELSE> &nbsp; <a href="./login.html">Personal information</a></TMPL_IF><br />
+         <TMPL_IF NAME="registration"> &nbsp; <b>Registration</b><TMPL_ELSE> &nbsp; <a href="<TMPL_VAR NAME="cgi_path">/registration.html">Registration</a></TMPL_IF><br />
+         <TMPL_IF NAME="list_people"> &nbsp; <b>List participants</b><TMPL_ELSE> &nbsp; <a href="<TMPL_VAR NAME="cgi_path">/list_people.html">List participants</a></TMPL_IF><br />
+         <TMPL_IF NAME="login"> &nbsp; <b>Personal information</b><TMPL_ELSE> &nbsp; <a href="<TMPL_VAR NAME="cgi_path">/login.html">Personal information</a></TMPL_IF><br />
          Call for Participation<br />
-         <TMPL_IF NAME="cfpenglish"> &nbsp; <b>English</b><TMPL_ELSE> &nbsp; <a href="./html/announcement.html">English</a></TMPL_IF><br />
-         <TMPL_IF NAME="cfphebrew"> &nbsp; <b>Hebrew</b><TMPL_ELSE> &nbsp; <a href="./html/announcement-il.html">Hebrew</a></TMPL_IF><br />
+         <TMPL_IF NAME="cfpenglish"> &nbsp; <b>English</b><TMPL_ELSE> &nbsp; <a href="/jonhtml/announcement.html">English</a></TMPL_IF><br />
+         <TMPL_IF NAME="cfphebrew"> &nbsp; <b>Hebrew</b><TMPL_ELSE> &nbsp; <a href="/jonhtml/announcement-il.html">Hebrew</a></TMPL_IF><br />
          Call for Papers<br />
-         <TMPL_IF NAME="callfphebrew"> &nbsp; <b>Hebrew (.doc)</b><TMPL_ELSE> &nbsp; <a href="./docs/announcement_call_for_papers_hebrew.doc">Hebrew (.doc)</a></TMPL_IF><br />
-         <TMPL_IF NAME="callfpenglish"> &nbsp; <b>English (.doc)</b><TMPL_ELSE> &nbsp; <a href="./docs/announcement_call_for_papers_english.doc">English (.doc)</a></TMPL_IF><br />
-         <TMPL_IF NAME="speakers"><b>Speakers</b><TMPL_ELSE><a href="./speakers.html">Speakers</a></TMPL_IF><br />
-         <TMPL_IF NAME="presentations"><b>Presentations</b><TMPL_ELSE><a href="./presentations.html">Presentations</a></TMPL_IF><br />
+         <TMPL_IF NAME="callfphebrew"> &nbsp; <b>Hebrew (.doc)</b><TMPL_ELSE> &nbsp; <a href="/jondocs/announcement_call_for_papers_hebrew.doc">Hebrew (.doc)</a></TMPL_IF><br />
+         <TMPL_IF NAME="callfpenglish"> &nbsp; <b>English (.doc)</b><TMPL_ELSE> &nbsp; <a href="/jondocs/announcement_call_for_papers_english.doc">English (.doc)</a></TMPL_IF><br />
+         <TMPL_IF NAME="speakers"><b>Speakers</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/speakers.html">Speakers</a></TMPL_IF><br />
+         <TMPL_IF NAME="presentations"><b>Presentations</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/presentations.html">Presentations</a></TMPL_IF><br />
          Slides<br />
          Pictures<br />
          Schedule<br />
          Training<br />
-         <TMPL_IF NAME="organizers"><b>Organizers</b><TMPL_ELSE><a href="./organizers.html">Organizers</a></TMPL_IF><br />
-         <TMPL_IF NAME="sponsors"><b>Sponsors</b><TMPL_ELSE><a href="./sponsors.html">Sponsors</a></TMPL_IF><br />
-         <TMPL_IF NAME="location"><b>Location</b><TMPL_ELSE><a href="./location.html">Location</a></TMPL_IF><br />
-         <TMPL_IF NAME="other_yapc"><b>Other YAPCs</b><TMPL_ELSE><a href="./other_yapc.html">Other YAPCs</a></TMPL_IF><br />
+         <TMPL_IF NAME="organizers"><b>Organizers</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/organizers.html">Organizers</a></TMPL_IF><br />
+         <TMPL_IF NAME="sponsors"><b>Sponsors</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">Sponsors</a></TMPL_IF><br />
+         <TMPL_IF NAME="location"><b>Location</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/location.html">Location</a></TMPL_IF><br />
+         <TMPL_IF NAME="other_yapc"><b>Other YAPCs</b><TMPL_ELSE><a href="<TMPL_VAR NAME="cgi_path">/other_yapc.html">Other YAPCs</a></TMPL_IF><br />
          <hr class="partruler" />
          <a href="http://perl.org.il">perl.org.il</a><br />
-         <a href="./download/">yapcom v<TMPL_VAR NAME="VERSION"></a>
+         <a href="/YAPC/2004/download/">yapcom v<TMPL_VAR NAME="VERSION"></a>

Modified: yapcom/trunk/templates/news.tmpl
===================================================================
--- yapcom/trunk/templates/news.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/news.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -8,13 +8,13 @@
             <tr>
                <td width="150" valign="top">2003 November 22</td>
                <td>
-                <a href="http://www.activestate.com">ActiveState</a>; is <a href="./sponsors.html">sponsoring</a> our conference.
+                <a href="http://www.activestate.com">ActiveState</a>; is <a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">sponsoring</a> our conference.
                </td>
             </tr>
             <tr>
                <td width="150" valign="top">2003 November 12</td>
                <td>
-                <a href="./registration.html">Registration</a> to YAPC::Israel::2004 is now open.
+                <a href="<TMPL_VAR NAME="cgi_path">/registration.html">Registration</a> to YAPC::Israel::2004 is now open.
                </td>
             </tr>
 
@@ -25,7 +25,7 @@
                   The conference will be held on 26th February 2004 in
                   <a href="http://www.idc.ac.il/">The Interdisciplinary Center Herzliya</a>
                   <br />
-                  (we also updated the <a href="./milestones.html">milestones</a> accordingly)
+                  (we also updated the <a href="<TMPL_VAR NAME="cgi_path">/milestones.html">milestones</a> accordingly)
                </td>
             </tr>
             <tr>

Modified: yapcom/trunk/templates/organizers.tmpl
===================================================================
--- yapcom/trunk/templates/organizers.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/organizers.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -17,7 +17,7 @@
        <li> Site layout (blame me) </li>
        <li> English text of the site </li>
        <li> Development of the registration and management software 
-            <a href="./download/">Yapcom</a> </li>
+            <a href="/YAPC/2004/download/">Yapcom</a> </li>
        <li> Charging money </li>
      </ul>
    </td>

Modified: yapcom/trunk/templates/person.tmpl
===================================================================
--- yapcom/trunk/templates/person.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/person.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -38,13 +38,13 @@
 Proposals:
 <table border="1">
 <TMPL_LOOP NAME="proposals">
-<tr><td><a href="propsal.htm?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="title"></a></td></tr>
+<tr><td><a href="<TMPL_VAR NAME="cgi_path">/proposal.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="title"></a></td></tr>
 </TMPL_LOOP>
 </table>
 </td></tr></table>
 </TMPL_IF>
 <p />
-<TMPL_IF NAME="owner"><a href=personal_info.html>change this page</a></TMPL_IF>
+<TMPL_IF NAME="owner"><a href="<TMPL_VAR NAME="cgi_path">/personal_info.html">change this page</a></TMPL_IF>
 <p />
 <TMPL_INCLUDE NAME="footer.tmpl">
 <p />

Modified: yapcom/trunk/templates/speakers.tmpl
===================================================================
--- yapcom/trunk/templates/speakers.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/speakers.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -5,7 +5,7 @@
 This page will list details about the speakers.
 </p>
 <p>
-If you would like to <a href="./presentations.html">give a presentation</a> you are welcome
+If you would like to <a href="<TMPL_VAR NAME="cgi_path">/presentations.html">give a presentation</a> you are welcome
 to follow the instructions on how to submit a proposal.
 </p>
 <TMPL_INCLUDE NAME="footer.tmpl">

Modified: yapcom/trunk/templates/sponsors.tmpl
===================================================================
--- yapcom/trunk/templates/sponsors.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/sponsors.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -2,7 +2,7 @@
 <TMPL_INCLUDE NAME="header.tmpl">
 YAPC is a low budget conference, we try to keep both our expenses and the fee we charge as low 
 as possible. Still we do have expenses, hence we are looking for sponsors to finance the 
-following items and other general expenses. <a href="./sponsorship.html">Further notes for the potential sponsors</a>.
+following items and other general expenses. <a href="<TMPL_VAR NAME="cgi_path">/sponsorship.html">Further notes for the potential sponsors</a>.
       <p>
 
          <table border="1">
@@ -71,7 +71,7 @@
         </table>
       </p>
       <p>
-      If you are interested in sponsoring this event you can read <a href="./sponsorship.html">further details 
+      If you are interested in sponsoring this event you can read <a href="<TMPL_VAR NAME="cgi_path">/sponsorship.html">further details 
 for sponsors</a> or contact Leah Siegel at <a href="http://www.pti.co.il/contact.html">PTI</a>;.
       </p>
 <TMPL_INCLUDE NAME="footer.tmpl">

Modified: yapcom/trunk/templates/sponsorship.tmpl
===================================================================
--- yapcom/trunk/templates/sponsorship.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/sponsorship.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -27,7 +27,7 @@
      <li> We mention them in e-mails sent to conference registrants several times before and
           after the conference.</li>
      <li> We display the logo they supply with a few words about what do they do 
-          on <a href="./sponsors.html">our web site</a></li>
+          on <a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">our web site</a></li>
      <li> We put the logo they supply on the first internal page of the printed proceedings
           of the conference that we hand out to the participants.</li>
      <li> Each sponsor will be mentioned individually at the opening and the final assembly thanks
@@ -53,7 +53,7 @@
             (if you want we will display the amount you gave next to your name or we can keep it confidential. It is up to you.)</li>
        <li> You can finance some of our expenses directly. (E.g. you can print all our proceedings
             yourself as Mercury did last year.)
-            (see examples for such items at the list of our <a href="./sponsors.html">sponsors</a>)</li>
+            (see examples for such items at the list of our <a href="<TMPL_VAR NAME="cgi_path">/sponsors.html">sponsors</a>)</li>
        <li> You can give presents (relevant books, internet access, software license, etc.)
             that we will either give away as we did last year or we'll auction out as done in
             YAPC::EU at the end of the conference.</li>

Modified: yapcom/trunk/templates/talk.tmpl
===================================================================
--- yapcom/trunk/templates/talk.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/talk.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -3,7 +3,7 @@
 <p>
 <table>
 <tr><td>Title: <b><TMPL_VAR NAME="title"></b></td></tr>
-<tr><td>Person: <a href="person.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="fname"> <TMPL_VAR NAME="lname"></a></td></tr>
+<tr><td>Person: <a href="<TMPL_VAR NAME="cgi_path">/person.html?id=<TMPL_VAR NAME="id">"><TMPL_VAR NAME="fname"> <TMPL_VAR NAME="lname"></a></td></tr>
 <tr><td>Length: <TMPL_VAR NAME="length"></td></tr>
 <tr><td>Language: <TMPL_VAR NAME="language"></td></tr>
 <tr><td>Abstract:<br>

Modified: yapcom/trunk/templates/user_account.tmpl
===================================================================
--- yapcom/trunk/templates/user_account.tmpl	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/templates/user_account.tmpl	2003-12-04 14:21:09 UTC (rev 108)
@@ -5,17 +5,17 @@
 <p>
 Some user information will be here.
 <p>
-<a href="./proposal.html">Submit a proposal</a><br />
-<a href="./change_password.html">Change password</a><br />
-<a href="./personal_info.html">Change personal information</a><br />
-<a href="./list_my_proposals.html">List my proposals</a><br />
-<a href="./logout.html">Logout</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/proposal.html">Submit a proposal</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/change_password.html">Change password</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/personal_info.html">Change personal information</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/list_my_proposals.html">List my proposals</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/logout.html">Logout</a><br />
 
 <TMPL_IF NAME="admin">
 <p>
 Administrative interface:<br />
-<a href="./list_people.html">List people</a><br />
-<a href="./admin_list_proposals.html">List proposals</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/list_people.html">List people</a><br />
+<a href="<TMPL_VAR NAME="cgi_path">/admin_list_proposals.html">List proposals</a><br />
 </TMPL_IF>
 </p>
 <TMPL_INCLUDE NAME="footer.tmpl">

Generated at 16:40 on 04 Dec 2003 by mariachi 0.51
--- yapcom/trunk/lib/YAPC/Organizer.pm	2003-12-03 01:20:36 UTC (rev 107)
+++ yapcom/trunk/lib/YAPC/Organizer.pm	2003-12-04 14:21:09 UTC (rev 108)
@@ -15,6 +15,7 @@
 use HTML::Template;    # we use it explicitely hence we need it here.
 
 my $templates_dir = $YAPC::Config::templates_dir;
+my $cgi_path = $YAPC::Config::cgi_path;
 
 use base 'CGI::Application';
 use Data::Dumper;      # for playing with debugging
@@ -85,7 +86,7 @@
 
    if (not -e $filename) {
 
-      #warn "YAPC script called for not existing file. Original: '$ENV{REQUEST_URI}' cut down: '$filename'\n";
+      #warn "YAPC script called for not existing file. Original: '$ENV{PATH_INFO}' cut down: '$filename'\n";
       $self->prerun_mode('no_such_page');
    }
    $self->prerun_mode('default');
@@ -101,8 +102,8 @@
 
 sub get_page {
 
-   # REQUEST_URI looks like this:  /content.html
-   my $page = $ENV{REQUEST_URI} || '';
+   # PATH_INFO looks like this:  /content.html
+   my $page = $ENV{PATH_INFO} || '';
    $page =~ s@.*/@@;
    $page =~ s/\.html(\?.*)?$//;
    $page ||= 'index';
@@ -281,7 +282,7 @@
                          associate         => $q
      );
    $mail->param("authcode" => $person->authcode);
-   my $validation_url = "http://$ENV{HTTP_HOST}$ENV{REQUEST_URI}";
+   my $validation_url = "http://$ENV{HTTP_HOST}$cgi_path$ENV{PATH_INFO}";
    $validation_url =~ s/\w+.html$/validation.html/;
    $validation_url .= "?email=" . $person->email . "&authcode=" . $person->authcode;
    $mail->param("validation_url" => $validation_url);
@@ -309,6 +310,7 @@
          $h{$1} = $2;
       }
    };
+   $h{'cgi_path'} = $cgi_path;
 
    # eval, because sub dies if template doesn't exists
    my $t;
@@ -454,7 +456,7 @@
      } or return $t->output;    # on error
 
    # success
-   my $path = $ENV{REQUEST_URI};
+   my $path = "$cgi_path$ENV{PATH_INFO}";
    $path =~ s@[^/]*$@@;         # remove everything after last /
    my $cookie =
      $q->cookie(
@@ -522,7 +524,7 @@
    $self->send_email_with_validation_code($person);
    $self->send_email_to_admin_about_new_registration($person);
 
-   my $validation_url = "http://$ENV{HTTP_HOST}$ENV{REQUEST_URI}";
+   my $validation_url = "http://$ENV{HTTP_HOST}$cgi_path$ENV{PATH_INFO}";
    $validation_url =~ s/\w+.html$/validation.html/;
 
    $self->header_type('redirect');

Modified: yapcom/trunk/t/03-web-adduser.t
===================================================================